==> haskell-fgl-5.5.4.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.4.0
id: fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM
key: fgl-5.5.4.0-9LmntGux65f56KmvEYc3VM
license: BSD3
maintainer: Ivan.Miljenovic@gmail.com
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree
hidden-modules: Paths_fgl
abi: 8107c7ec0408e8805abfc786bf663252
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fgl-5.5.4.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/fgl-5.5.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/fgl-5.5.4.0
hs-libraries: HSfgl-5.5.4.0-9LmntGux65f56KmvEYc3VM
depends:
    base-4.10.1.0 transformers-0.5.2.0 array-0.5.2.0
    containers-0.5.10.2 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-5.5.4.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fgl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fgl
version: 5.5.4.0
id: fgl-5.5.4.0-GjaBXHxJNwQ4DdQJ8BFQ77
key: fgl-5.5.4.0-GjaBXHxJNwQ4DdQJ8BFQ77
license: BSD-3-Clause
maintainer: Ivan.Miljenovic@gmail.com
author: Martin Erwig, Ivan Lazar Miljenovic
synopsis: Martin Erwig'\''s Functional Graph Library
description:
    An inductive representation of manipulating graph data structures.
    .
    Original website can be found at <http://web.engr.oregonstate.edu/~erwig/fgl/haskell>.
category: Data Structures, Graphs
abi: 9c1e1ae8033eef667672403f6e88b99e
exposed: True
exposed-modules:
    Data.Graph.Inductive Data.Graph.Inductive.Basic
    Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
    Data.Graph.Inductive.Internal.Heap
    Data.Graph.Inductive.Internal.Queue
    Data.Graph.Inductive.Internal.RootPath
    Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Monad
    Data.Graph.Inductive.Monad.IOArray
    Data.Graph.Inductive.Monad.STArray Data.Graph.Inductive.NodeMap
    Data.Graph.Inductive.PatriciaTree Data.Graph.Inductive.Query
    Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
    Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
    Data.Graph.Inductive.Query.Dominators
    Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
    Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
    Data.Graph.Inductive.Query.MaxFlow2
    Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
    Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive.Tree
hidden-modules: Paths_fgl
import-dirs: /usr/lib/ghc-8.4.2/site-local/fgl-5.5.4.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/fgl-5.5.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/fgl-5.5.4.0
hs-libraries: HSfgl-5.5.4.0-GjaBXHxJNwQ4DdQJ8BFQ77
depends:
    base-4.11.1.0 transformers-0.5.5.0 array-0.5.2.0
    containers-0.5.11.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
haddock-interfaces: /usr/share/doc/haskell-fgl/html/fgl.haddock
haddock-html: /usr/share/doc/haskell-fgl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
